@@ -63,8 +63,8 @@ response_cb (GtkDialog  *widget,
 
 	switch (response_id) {
 	case GTK_RESPONSE_OK:
-		selected_files = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->d_selected_files_radio));
-		pattern_files = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->d_files_radio));
+		selected_files = gtk_check_button_get_active (GTK_CHECK_BUTTON (data->d_selected_files_radio));
+		pattern_files = gtk_check_button_get_active (GTK_CHECK_BUTTON (data->d_files_radio));
 
 		/* create the file list. */
 
@@ -75,7 +75,7 @@ response_cb (GtkDialog  *widget,
 		else if (pattern_files) {
 			const char *pattern;
 
-			pattern = gtk_entry_get_text (GTK_ENTRY (data->d_files_entry));
+			pattern = gtk_editable_get_text (GTK_EDITABLE (data->d_files_entry));
 			file_list = fr_window_get_file_list_pattern (window, pattern);
 			if (file_list == NULL)
 				do_not_remove_if_null = TRUE;
@@ -91,7 +91,7 @@ response_cb (GtkDialog  *widget,
 	}
 
 	/* close the dialog. */
-	gtk_widget_destroy (data->dialog);
+	gtk_window_destroy (GTK_WINDOW (data->dialog));
 }
 
 
@@ -99,8 +99,8 @@ static void
 entry_changed_cb (GtkEditable *widget,
 		  DialogData *data)
 {
-	if (! gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->d_files_radio)))
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->d_files_radio), TRUE);
+	if (! gtk_check_button_get_active (GTK_CHECK_BUTTON (data->d_files_radio)))
+		gtk_check_button_set_active (GTK_CHECK_BUTTON (data->d_files_radio), TRUE);
 }
 
 
@@ -109,7 +109,6 @@ dlg_delete__common (FrWindow *window,
 	            GList    *selected_files)
 {
 	DialogData *data;
-	GtkWidget  *content_area;
 	GtkWidget  *delete_box;
 	GtkWidget  *ok_button;
 
@@ -125,7 +124,9 @@ dlg_delete__common (FrWindow *window,
 				     "transient-for", GTK_WINDOW (window),
 				     "modal", TRUE,
 				     "use-header-bar", _gtk_settings_get_dialogs_use_header (),
+				     "title", _("Delete"),
 				     NULL);
+	gtk_window_set_default_size (GTK_WINDOW (data->dialog), 500, -1);
 
 	gtk_dialog_add_buttons (GTK_DIALOG (data->dialog),
 				_GTK_LABEL_CANCEL, GTK_RESPONSE_CANCEL,
@@ -142,16 +143,15 @@ dlg_delete__common (FrWindow *window,
 	data->d_files_radio = _gtk_builder_get_widget (data->builder, "d_files_radio");
 	data->d_files_entry = _gtk_builder_get_widget (data->builder, "d_files_entry");
 
-	content_area = gtk_dialog_get_content_area (GTK_DIALOG (data->dialog));
-	gtk_container_add (GTK_CONTAINER (content_area), delete_box);
+	gtk_box_append (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (data->dialog))), delete_box);
 
 	/* Set widgets data. */
 
 	if (data->selected_files != NULL)
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->d_selected_files_radio), TRUE);
+		gtk_check_button_set_active (GTK_CHECK_BUTTON (data->d_selected_files_radio), TRUE);
 	else {
 		gtk_widget_set_sensitive (data->d_selected_files_radio, FALSE);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->d_all_files_radio), TRUE);
+		gtk_check_button_set_active (GTK_CHECK_BUTTON (data->d_all_files_radio), TRUE);
 	}
 
 	/* Set the signals handlers. */
@@ -166,7 +166,7 @@ dlg_delete__common (FrWindow *window,
 			  data);
 //	g_signal_connect_swapped (GTK_BUTTON (cancel_button),
 //				  "clicked",
-//				  G_CALLBACK (gtk_widget_destroy),
+//				  G_CALLBACK (gtk_window_destroy),
 //				  G_OBJECT (data->dialog));
 //	g_signal_connect (GTK_BUTTON (ok_button),
 //			  "clicked",
@@ -178,7 +178,7 @@ dlg_delete__common (FrWindow *window,
 			  data);
 
 	/* Run dialog. */
-	gtk_widget_show (data->dialog);
+	gtk_window_present (GTK_WINDOW (data->dialog));
 }
 
 
