@@ -24,7 +24,7 @@
 #include <string.h>
 #include <time.h>
 #include <glib.h>
-#include "file-data.h"
+#include "fr-file-data.h"
 #include "file-utils.h"
 #include "glib-utils.h"
 #include "fr-command.h"
@@ -87,7 +87,7 @@ static void
 list__process_line (char     *line,
 		    gpointer  data)
 {
-	FileData    *fdata;
+	FrFileData *fdata;
 	FrCommand   *comm = FR_COMMAND (data);
 	char       **fields;
 	const char  *name_field;
@@ -96,7 +96,7 @@ list__process_line (char     *line,
 
 	g_return_if_fail (line != NULL);
 
-	fdata = file_data_new ();
+	fdata = fr_file_data_new ();
 
 #ifdef __sun
 	fields = _g_str_split_line (line, 9);
@@ -162,7 +162,7 @@ list__process_line (char     *line,
 	fdata->path = _g_path_remove_level (fdata->full_path);
 
 	if (*fdata->name == 0)
-		file_data_free (fdata);
+		fr_file_data_free (fdata);
 	else
 		fr_archive_add_file (FR_ARCHIVE (comm), fdata);
 }
@@ -199,7 +199,7 @@ fr_command_cpio_extract (FrCommand *comm,
                 fr_process_set_working_dir (comm->process, dest_dir);
 	fr_process_add_arg (comm->process, "-c");
 
-	cmd = g_string_new ("cpio -idu --no-absolute-filenames ");
+	cmd = g_string_new (CPIO_PATH " -idu --no-absolute-filenames ");
 	for (scan = file_list; scan; scan = scan->next) {
 		char *filepath = scan->data;
 		char *filename;
@@ -232,12 +232,12 @@ fr_command_cpio_get_mime_types (FrArchive *archive)
 }
 
 
-static FrArchiveCap
+static FrArchiveCaps
 fr_command_cpio_get_capabilities (FrArchive  *archive,
 			          const char *mime_type,
 				  gboolean    check_command)
 {
-	FrArchiveCap capabilities;
+	FrArchiveCaps capabilities;
 
 	capabilities = FR_ARCHIVE_CAN_STORE_MANY_FILES;
 	if (_g_program_is_available (CPIO_PATH, check_command))
@@ -251,7 +251,7 @@ static const char *
 fr_command_cpio_get_packages (FrArchive  *archive,
 			      const char *mime_type)
 {
-	return PACKAGES ("cpio");
+	return FR_PACKAGES ("cpio");
 }
 
 
