@@ -24,7 +24,7 @@
 #include <string.h>
 #include <time.h>
 #include <glib.h>
-#include "file-data.h"
+#include "fr-file-data.h"
 #include "file-utils.h"
 #include "glib-utils.h"
 #include "fr-command.h"
@@ -45,7 +45,7 @@ static void
 process_metadata_line (char      *line,
                        FrCommand *comm)
 {
-        FileData    *fdata;
+        FrFileData *fdata;
         char       **fields;
         char        *name;
 
@@ -57,7 +57,7 @@ process_metadata_line (char      *line,
                 return;
         }
 
-        fdata = file_data_new ();
+        fdata = fr_file_data_new ();
         fdata->size = g_ascii_strtoull (fields[0], NULL, 10);
 
         if (fields[5] && g_str_equal (fields[4],"*")) {
@@ -71,9 +71,9 @@ process_metadata_line (char      *line,
         fdata->original_path = fdata->full_path + 1;
 
         g_strfreev (fields);
-        g_free (name);
 
         fdata->name = g_strdup (name);
+        g_free (name);
         fdata->path = g_strdup ("DEBIAN");
         fr_archive_add_file (FR_ARCHIVE (comm), fdata);
 }
@@ -82,7 +82,7 @@ static void
 process_data_line (char     *line,
                    gpointer  data)
 {
-        FileData    *fdata;
+        FrFileData *fdata;
         FrCommand   *comm = FR_COMMAND (data);
         char       **fields;
         char       **tmfields;
@@ -97,7 +97,7 @@ process_data_line (char     *line,
                 return;
         }
 
-        fdata = file_data_new ();
+        fdata = fr_file_data_new ();
 
         fields = _g_str_split_line (line, 5);
         fdata->size = g_ascii_strtoull (fields[2], NULL, 10);
@@ -151,7 +151,7 @@ process_data_line (char     *line,
         fdata->path = _g_path_remove_level (fdata->full_path);
 
         if (*fdata->name == 0)
-                file_data_free (fdata);
+                fr_file_data_free (fdata);
         else
                 fr_archive_add_file (FR_ARCHIVE (comm), fdata);
 }
@@ -219,12 +219,12 @@ fr_command_dpkg_get_mime_types (FrArchive *archive)
 }
 
 
-static FrArchiveCap
+static FrArchiveCaps
 fr_command_dpkg_get_capabilities (FrArchive  *archive,
                                   const char *mime_type,
                                   gboolean    check_command)
 {
-        FrArchiveCap capabilities;
+        FrArchiveCaps capabilities;
 
         capabilities = FR_ARCHIVE_CAN_STORE_MANY_FILES;
         if (_g_program_is_available ("dpkg-deb", check_command))
@@ -238,7 +238,7 @@ static const char *
 fr_command_dpkg_get_packages (FrArchive  *archive,
                               const char *mime_type)
 {
-        return PACKAGES ("dpkg");
+        return FR_PACKAGES ("dpkg");
 }
 
 
