@@ -29,7 +29,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <json-glib/json-glib.h>
-#include "file-data.h"
+#include "fr-file-data.h"
 #include "file-utils.h"
 #include "gio-utils.h"
 #include "glib-utils.h"
@@ -89,16 +89,15 @@ list_command_completed (gpointer data)
 
 		if (json_object_get_int_member (root, "lsarFormatVersion") == LSAR_SUPPORTED_FORMAT) {
 			JsonArray *content;
-			int        i;
 
 			content = json_object_get_array_member (root, "lsarContents");
-			for (i = 0; i < json_array_get_length (content); i++) {
+			for (guint i = 0; i < json_array_get_length (content); i++) {
 				JsonObject *entry;
-				FileData   *fdata;
+				FrFileData *fdata;
 				const char *filename;
 
 				entry = json_array_get_object_element (content, i);
-				fdata = file_data_new ();
+				fdata = fr_file_data_new ();
 				if (json_object_has_member (entry, "XADFileSize"))
 					fdata->size = json_object_get_int_member (entry, "XADFileSize");
 				fdata->modified = mktime_from_string (json_object_get_string_member (entry, "XADLastModificationDate"));
@@ -256,6 +255,7 @@ fr_command_unarchiver_handle_error (FrCommand   *comm,
 
 const char *unarchiver_mime_type[] = { "application/x-cbr",
 				       "application/x-rar",
+				       "application/vnd.rar",
 				       NULL };
 
 
@@ -266,12 +266,12 @@ fr_command_unarchiver_get_mime_types (FrArchive *archive)
 }
 
 
-static FrArchiveCap
+static FrArchiveCaps
 fr_command_unarchiver_get_capabilities (FrArchive  *archive,
 					const char *mime_type,
 					gboolean    check_command)
 {
-	FrArchiveCap capabilities;
+	FrArchiveCaps capabilities;
 
 	capabilities = FR_ARCHIVE_CAN_DO_NOTHING;
 	if (_g_program_is_available ("lsar", check_command) && _g_program_is_available ("unar", check_command))
@@ -285,7 +285,7 @@ static const char *
 fr_command_unarchiver_get_packages (FrArchive  *archive,
 				    const char *mime_type)
 {
-	return PACKAGES ("unarchiver");
+	return FR_PACKAGES ("unarchiver");
 }
 
 
